@@ -143,7 +143,9 @@ void AutoUpdater::startDownload() {
             downloadProcessDialog->reset();
         }
         downloadProcessDialog->show();
-        QNetworkReply* reply = networkAccessManager->get(QNetworkRequest(downloadUrl));
+        QNetworkRequest request(downloadUrl);
+        request.setAttribute(QNetworkRequest::FollowRedirectsAttribute, true);
+        QNetworkReply* reply = networkAccessManager->get(request);
         connect(reply, &QNetworkReply::downloadProgress, this,
                 [=](qint64 bytesReceived, qint64 bytesTotal) {
                     AutoUpdater::onDownloadProgress(reply, bytesReceived, bytesTotal);
@@ -209,20 +211,7 @@ void AutoUpdater::onReleaseInfoRequestFinished(QNetworkReply* result) {
 }
 
 void AutoUpdater::onInstallerDownloadFinished(QNetworkReply* result) {
-    QVariant redirectionTarget = result->attribute(QNetworkRequest::RedirectionTargetAttribute);
-    if (!redirectionTarget.isNull()) {
-        QUrl newUrl = resolveRedirectDownloadUrl(redirectionTarget.toUrl());
-        if (newUrl.isValid()) {
-            downloadUrl = newUrl;
-            startDownload();
-            return;
-        } else {
-            QMessageBox::critical(
-                    nullptr, tr("Installer download failed"),
-                    tr("Failed to download the Birdtray installer:\n") + tr("Invalid redirect: ")
-                    + redirectionTarget.toString(), QMessageBox::StandardButton::Abort);
-        }
-    } else if (installerFile.write(result->readAll()) == -1) {
+    if (installerFile.write(result->readAll()) == -1) {
         QString errorMessage(tr("Failed to save the Birdtray installer:\n")
                              + installerFile.errorString());
         installerFile.remove();
@@ -269,19 +258,6 @@ void AutoUpdater::onDownloadProgress(QNetworkReply* result, qint64 bytesReceived
     }
 }
 
-QUrl AutoUpdater::resolveRedirectDownloadUrl(const QUrl &redirectUrl) const {
-    QUrl newUrl;
-    if (redirectUrl.isRelative()) {
-        newUrl = downloadUrl.resolved(redirectUrl);
-    } else {
-        newUrl = redirectUrl;
-    }
-    if (!newUrl.isEmpty() && newUrl != downloadUrl) {
-        return newUrl;
-    }
-    return QUrl();
-}
-
 bool AutoUpdater::versionGrater(const int (&version)[3], const int (&other)[3]) {
     return version[0] > other[0] || (version[0] == other[0] && (
             version[1] > other[1] || (version[1] == other[1] && version[2] > other[2])));
