@@ -64,11 +64,14 @@ DialogSettings::DialogSettings( QWidget *parent)
     boxHideWhenMinimized->setChecked( settings->mHideWhenMinimized );
     boxMonitorThunderbirdWindow->setChecked( settings->mMonitorThunderbirdWindow );
     boxRestartThunderbird->setChecked( settings->mRestartThunderbird );
+    leThunderbirdProcessName->setText( settings->mThunderbirdProcessName );
     leThunderbirdWindowMatch->setText( settings->mThunderbirdWindowMatch  );
     spinMinimumFontSize->setValue( settings->mNotificationMinimumFontSize );
     spinMinimumFontSize->setMaximum( settings->mNotificationMaximumFontSize - 1 );
     boxHideWindowAtStart->setChecked( settings->mHideWhenStarted );
     boxHideWindowAtRestart->setChecked( settings->mHideWhenRestarted );
+    boxStartThunderbirdOnTrayIconClick->setChecked( settings->startClosedThunderbird );
+    boxHideWindowAfterManualStart->setChecked( settings->hideWhenStartedManually );
     boxEnableNewEmail->setChecked( settings->mNewEmailMenuEnabled );
     boxBlinkingUsesAlpha->setChecked( settings->mBlinkingUseAlphaTransition );
     checkUpdateOnStartup->setChecked( settings->mUpdateOnStartup );
@@ -76,10 +79,12 @@ DialogSettings::DialogSettings( QWidget *parent)
     spinUnreadOpacityLevel->setValue( settings->mUnreadOpacityLevel * 100 );
     spinThunderbirdStartDelay->setValue( settings->mLaunchThunderbirdDelay );
     boxShowUnreadCount->setChecked( settings->mShowUnreadEmailCount );
-    ignoreStartupMailCountBox->setChecked(settings->ignoreStartUnreadCount);
+    ignoreMailCountOnStartupBox->setChecked(settings->ignoreUnreadCountOnStart);
+    ignoreMailCountOnShowBox->setChecked(settings->ignoreUnreadCountOnShow);
+    ignoreMailCountOnHideBox->setChecked(settings->ignoreUnreadCountOnHide);
     onlyShowIconOnNewMail->setChecked(settings->onlyShowIconOnUnreadMessages);
     leProcessRunOnCountChange->setText( settings->mProcessRunOnCountChange );
-    boxIgnoreEmailsOnMinimize->setChecked(settings->mForceIgnoreUnreadEmailsOnMinimize);
+    boxSupportNonNetwmCompliant->setChecked( settings->mIgnoreNETWMhints );
 
     if ( settings->mIndexFilesRereadIntervalSec > 0 )
     {
@@ -88,6 +93,7 @@ DialogSettings::DialogSettings( QWidget *parent)
     }
     else
         boxForceReread->setChecked( false );
+    spinWatchFileTimerMilliseconds->setValue( static_cast<int>(settings->mWatchFileTimeout) );
 
     // Form the proper command-line (with escaped arguments if they contain spaces
     QString tbcmdline;
@@ -133,6 +139,15 @@ DialogSettings::DialogSettings( QWidget *parent)
         boxNotificationIconUnread->setChecked(false);
         btnNotificationIconUnread->setDisabled(true);
     }
+
+#if defined (Q_OS_WINDOWS)
+    leThunderbirdWindowMatch->hide();
+    labelWindowNamePattern->hide();
+    boxSupportNonNetwmCompliant->hide();
+#else
+    processNameLabel->hide();
+    leThunderbirdProcessName->hide();
+#endif
 }
 
 void DialogSettings::accept()
@@ -149,27 +164,35 @@ void DialogSettings::accept()
     settings->mLaunchThunderbird = boxLaunchThunderbirdAtStart->isChecked();
     settings->mShowHideThunderbird = boxShowHideThunderbird->isChecked();
     settings->mThunderbirdCmdLine = Utils::splitCommandLine( leThunderbirdCmdLine->text() );
+    settings->mThunderbirdProcessName = leThunderbirdProcessName->text();
     settings->mThunderbirdWindowMatch = leThunderbirdWindowMatch->text();
     settings->mHideWhenMinimized = boxHideWhenMinimized->isChecked();
     settings->mNotificationFontWeight = qMin(99, (int) (notificationFontWeight->value() / 2));
     settings->mExitThunderbirdWhenQuit = boxStopThunderbirdOnExit->isChecked();
     settings->mAllowSuppressingUnreads = boxAllowSuppression->isChecked();
-    settings->mForceIgnoreUnreadEmailsOnMinimize = boxIgnoreEmailsOnMinimize->isChecked();
 
     settings->mMonitorThunderbirdWindow = boxMonitorThunderbirdWindow->isChecked();    
     settings->mNotificationMinimumFontSize = spinMinimumFontSize->value();
     settings->mRestartThunderbird = boxRestartThunderbird->isChecked();
     settings->mHideWhenStarted = boxHideWindowAtStart->isChecked();
     settings->mHideWhenRestarted = boxHideWindowAtRestart->isChecked();
+    settings->startClosedThunderbird = boxStartThunderbirdOnTrayIconClick->isChecked();
+    settings->hideWhenStartedManually = boxHideWindowAfterManualStart->isChecked();
     settings->mNewEmailMenuEnabled = boxEnableNewEmail->isChecked();
     settings->mBlinkingUseAlphaTransition = boxBlinkingUsesAlpha->isChecked();
     settings->mUpdateOnStartup = checkUpdateOnStartup->isChecked();
     settings->mUnreadOpacityLevel = (double) spinUnreadOpacityLevel->value() / 100.0;
     settings->mLaunchThunderbirdDelay = spinThunderbirdStartDelay->value();
     settings->mShowUnreadEmailCount = boxShowUnreadCount->isChecked();
-    settings->ignoreStartUnreadCount = ignoreStartupMailCountBox->isChecked();
+    settings->ignoreUnreadCountOnStart = settings->mAllowSuppressingUnreads &&
+            ignoreMailCountOnStartupBox->isChecked();
+    settings->ignoreUnreadCountOnShow = settings->mAllowSuppressingUnreads &&
+            ignoreMailCountOnShowBox->isChecked();
+    settings->ignoreUnreadCountOnHide = settings->mAllowSuppressingUnreads &&
+            ignoreMailCountOnHideBox->isChecked();
     settings->onlyShowIconOnUnreadMessages = onlyShowIconOnNewMail->isChecked();
     settings->mProcessRunOnCountChange = leProcessRunOnCountChange->text();
+    settings->mIgnoreNETWMhints = boxSupportNonNetwmCompliant->isChecked();
 
     settings->setNotificationIcon(btnNotificationIcon->icon().pixmap( settings->mIconSize ));
 
@@ -182,6 +205,8 @@ void DialogSettings::accept()
         settings->mIndexFilesRereadIntervalSec = spinForceRereadSeconds->value();
     else
         settings->mIndexFilesRereadIntervalSec = 0;
+    
+    settings->mWatchFileTimeout = spinWatchFileTimerMilliseconds->value();
 
     mModelNewEmails->applySettings();
     mAccountModel->applySettings();
