@@ -83,7 +83,8 @@ bool MorkParser::open( const QString &path )
     // Open file
     if ( !MorkFile.exists() || !MorkFile.open( QIODevice::ReadOnly ) )
     {
-        mErrorMessage = QCoreApplication::tr("Couldn't open file: ") + MorkFile.errorString();
+        mErrorMessage = QCoreApplication::translate(
+                "MorkParser", "Couldn't open file: ") + MorkFile.errorString();
         return false;
     }
 
@@ -92,7 +93,7 @@ bool MorkParser::open( const QString &path )
 
     if ( !MagicHeader.contains( MorkMagicHeader ) )
     {
-        mErrorMessage = QCoreApplication::tr("Unsupported version.");
+        mErrorMessage = QCoreApplication::translate("MorkParser", "Unsupported version.");
         return false;
     }
 
@@ -112,7 +113,7 @@ bool MorkParser::open( const QString &path )
 //	=============================================================
 //	MorkParser::error
 
-inline QString MorkParser::errorMsg()
+QString MorkParser::errorMsg()
 {
     return mErrorMessage;
 }
@@ -172,8 +173,8 @@ void MorkParser::parse()
                 break;
 
             default:
-                throw MorkParserException(QCoreApplication::tr("Invalid format."));
-                break;
+                throw MorkParserException(QCoreApplication::translate(
+                        "MorkParser", "Invalid format."));
             }
         }
 
@@ -226,7 +227,7 @@ void MorkParser::skip( const char * string )
     while ( *string )
     {
         if (*string != nextChar()) {
-            throw MorkParserException(QCoreApplication::tr("Parsing error."));
+            throw MorkParserException(QCoreApplication::translate("MorkParser", "Parsing error."));
         }
         string++;
     }
@@ -242,7 +243,7 @@ QChar MorkParser::readNext()
 QChar MorkParser::peekNext()
 {
     if (morkPos_ >= morkData_.length()) {
-        throw MorkParserException(QCoreApplication::tr("Unexpected EOF."));
+        throw MorkParserException(QCoreApplication::translate("MorkParser", "Unexpected EOF."));
     }
     return QChar( morkData_[ morkPos_ ] );
 }
@@ -306,7 +307,7 @@ inline void MorkParser::parseComment()
     char cur = nextChar();
 
     if ( '/' != cur ) {
-        throw MorkParserException(QCoreApplication::tr("Invalid comment."));
+        throw MorkParserException(QCoreApplication::translate("MorkParser", "Invalid comment."));
     }
 
     while ( cur != '\r' && cur != '\n' && cur )
@@ -617,8 +618,8 @@ void MorkParser::parseRow( int TableId, int TableScope )
                 parseMeta( ']' );
                 break;
             default:
-                throw MorkParserException(QCoreApplication::tr("Format error."));
-                break;
+                throw MorkParserException(QCoreApplication::translate(
+                        "MorkParser", "Format error."));
             }
         }
 
@@ -662,7 +663,8 @@ void MorkParser::parseGroup()
     ofst = morkData_.indexOf( endCommit, morkPos_ );
 
     if (ofst == -1) {
-        throw MorkParserException(QCoreApplication::tr("Unexpected end of group."));
+        throw MorkParserException(QCoreApplication::translate(
+                "MorkParser", "Unexpected end of group."));
     }
     // Transaction succeeded. Copy the transaction data
     QByteArray transaction = morkData_.mid( morkPos_, ofst - morkPos_ );
@@ -788,7 +790,7 @@ int MorkParser::dumpMorkFile( const QString& filename )
 
     for ( TableScopeMap::iterator tit = p.mork_.begin(); tit != p.mork_.end(); ++tit )
     {
-        printf("Table scope %02X\n", tit.key() );
+        printf("Table scope %02X (%s)\n", tit.key(), qPrintable(p.getColumn(tit.key())) );
         const MorkTableMap& map = tit.value();
 
         for ( MorkTableMap::const_iterator mit = map.begin(); mit != map.end(); ++mit )
@@ -799,7 +801,7 @@ int MorkParser::dumpMorkFile( const QString& filename )
 
             for ( RowScopeMap::const_iterator rsit = rowscopemap.begin(); rsit != rowscopemap.end(); ++rsit )
             {
-                printf("    Row scope %02X\n", rsit.key() );
+                printf("    Row scope %02X (%s)\n", rsit.key(), qPrintable(p.getColumn(rsit.key())) );
 
                 const MorkRowMap& rows = rsit.value();
 
@@ -825,7 +827,12 @@ int MorkParser::dumpMorkFile( const QString& filename )
 }
 
 unsigned int MailMorkParser::getNumUnreadMessages() {
-    const MorkRowMap* rows = this->rows(0x9F, 1, 0x9F);
+    const int scopeId = this->columns_.key(MorkDbFolderInfoScope);
+    if (!scopeId) {
+        Log::debug("Mork table %s not found", MorkDbFolderInfoScope);
+        return 0;
+    }
+    const MorkRowMap* rows = this->rows(scopeId, 1, scopeId);
     if (rows) {
         for (MorkRowMap::const_iterator rit = rows->begin(); rit != rows->cend(); rit++) {
             MorkCells cells = rit.value();
