@@ -9,6 +9,7 @@
 #include <QSettings>
 
 #include "setting_newemail.h"
+#include "utils.h"
 
 class QSettings;
 
@@ -57,6 +58,9 @@ class Settings
         // The command to start Thunderbird. The first element is the executable to launch.
         QStringList mThunderbirdCmdLine;
 
+        // The name of the Thunderbird process.
+        QString mThunderbirdProcessName;
+
         // Thunderbird window match
         QString mThunderbirdWindowMatch;
 
@@ -84,6 +88,12 @@ class Settings
         // Whether to hide Thunderbird window after restarting
         bool    mHideWhenRestarted;
 
+        // Whether to start Thunderbird if it is closed and the user clicks on the tray icon
+        bool    startClosedThunderbird;
+    
+        // Whether to hide Thunderbird window after starting it via the system tray icon
+        bool    hideWhenStartedManually;
+
         // Whether to monitor Thunderbird running
         bool    mMonitorThunderbirdWindow;
 
@@ -101,14 +111,21 @@ class Settings
 
         // Whether to show the unread email count
         bool    mShowUnreadEmailCount;
-
-        // Whether to ignore all currently unread emails if Thunderbird is hidden by Birdtray
-        bool    mForceIgnoreUnreadEmailsOnMinimize;
         
         /**
          * Ignore the total number of unread emails that are present at startup.
          */
-        bool    ignoreStartUnreadCount;
+        bool    ignoreUnreadCountOnStart;
+        
+        /**
+         * Ignore the number of unread emails when showing Thunderbird.
+         */
+        bool    ignoreUnreadCountOnShow;
+    
+        /**
+         * Ignore the number of unread emails when hiding Thunderbird.
+         */
+        bool    ignoreUnreadCountOnHide;
         
         /**
          * Enables or disabled the dialog on startup that shows if no accounts were configured.
@@ -131,17 +148,21 @@ class Settings
         bool    mNewEmailMenuEnabled;
         QList< Setting_NewEmail >   mNewEmailData;
 
-        // Maps the folder path to the notification color.
-        // The original order of strings is stored in mFolderNotificationList (to show in UI)
-        QMap< QString, QColor >   mFolderNotificationColors;
-        QStringList               mFolderNotificationList;
+        /**
+         * A mapping of watched mork files to their notification color
+         * in the order the user added them.
+         */
+        OrderedMap<QString, QColor> watchedMorkFiles;
 
         // If non-zero, specifies an interval in seconds for rereading index files even if they didn't change. 0 disables.
         unsigned int    mIndexFilesRereadIntervalSec;
 
-        // When the number of unread emails changes, birdtray can start this process
+        // When the number of unread emails changes, Birdtray can start this process
         QString                   mProcessRunOnCountChange;
 
+        // Whether to support non-compliant NetWM WMs by ignoring NETWM hints
+        bool                      mIgnoreNETWMhints;
+
         // Load and save them
         void    save();
         void    load();
@@ -166,6 +187,8 @@ class Settings
         void setNotificationIcon(const QPixmap& icon);
 
     private:
+        Q_DECLARE_TR_FUNCTIONS(Settings)
+    
         // Loading from either storage
         void    fromJSON( const QJsonObject& settings );
 
