@@ -9,256 +9,298 @@
         <translation>PortugueseBR</translation>
     </message>
     <message>
-        <source>BirdtraySectionDescription</source>
+        <source>A free system tray notification for new mail for Thunderbird.</source>
         <translation>Notificação de novos e-mails do Thunderbird direto da Área de Notificação.</translation>
     </message>
     <message>
-        <source>WinIntegrationSectionName</source>
+        <source>Windows integration</source>
         <translation>Integração com o Windows</translation>
     </message>
     <message>
-        <source>WinIntegrationGroupDescription</source>
+        <source>Select how to integrate the program in Windows.</source>
         <translation>Selecione como integrar o programa no Windows.</translation>
     </message>
     <message>
-        <source>AutoRunSectionName</source>
+        <source>AutoRun</source>
         <translation>Execução Automática</translation>
     </message>
     <message>
-        <source>AutoRunDescription</source>
+        <source>Automatically start ${PRODUCT_NAME} after login.</source>
         <translation>Automaticamente inicia o ${PRODUCT_NAME} após fazer login.</translation>
     </message>
     <message>
-        <source>AutoCheckUpdateSectionName</source>
+        <source>Auto Update-Check</source>
         <translation>Verificação Automática de Atualizações</translation>
     </message>
     <message>
-        <source>AutoCheckUpdateDescription</source>
+        <source>Automatically search for updates of ${PRODUCT_NAME} at startup.</source>
         <translation>Automaticamente busca por atualizações do ${PRODUCT_NAME} ao iniciar.</translation>
     </message>
     <message>
-        <source>ProgramGroupSectionName</source>
+        <source>Program Group Entry</source>
         <translation>Entrada do Grupo de Programas</translation>
     </message>
     <message>
-        <source>ProgramGroupDescription</source>
+        <source>Create a ${PRODUCT_NAME} program group under Start Menu > Programs.</source>
         <translation>Cria o grupo do programa ${PRODUCT_NAME} em Menu Iniciar &gt; Programas.</translation>
     </message>
     <message>
-        <source>DesktopEntrySectionName</source>
+        <source>Desktop Entry</source>
         <translation>Ícone na Área de Trabalho</translation>
     </message>
     <message>
-        <source>DesktopEntryDescription</source>
+        <source>Create a ${PRODUCT_NAME} icon on the Desktop.</source>
         <translation>Cria um ícone do ${PRODUCT_NAME} na Área de Trabalho.</translation>
     </message>
     <message>
-        <source>StartMenuSectionName</source>
+        <source>Start Menu Entry</source>
         <translation>Entrada no Menu Iniciar</translation>
     </message>
     <message>
-        <source>StartMenuDescription</source>
+        <source>Create a ${PRODUCT_NAME} icon in the Start Menu.</source>
         <translation>Cria um ícone do ${PRODUCT_NAME} no Menu Iniciar.</translation>
     </message>
     <message>
-        <source>TranslationsSectionName</source>
+        <source>Translations</source>
         <translation>Traduções</translation>
     </message>
     <message>
-        <source>TranslationsDescription</source>
+        <source>Select translations for ${PRODUCT_NAME}. ${PRODUCT_NAME} will choose a translation based on the system language.</source>
         <translation>Selecione as traduções para o ${PRODUCT_NAME}. O ${PRODUCT_NAME} irá escolher uma tradução baseada no idioma do sistema.</translation>
     </message>
     <message>
-        <source>UserSettingsSectionName</source>
+        <source>${PRODUCT_NAME} User Settings</source>
         <translation>Configurações do Usuário do ${PRODUCT_NAME}</translation>
     </message>
     <message>
-        <source>UserSettingsDescription</source>
+        <source>Your settings and configuration made within ${PRODUCT_NAME}.</source>
         <translation>Suas definições e configurações feitas dentro do ${PRODUCT_NAME}.</translation>
     </message>
     <message>
-        <source>LicenseStartMenuLinkName</source>
+        <source>License Agreement</source>
         <translation>Contrato de Licença</translation>
     </message>
     <message>
-        <source>FinishPageRunBirdtray</source>
+        <source>Start ${PRODUCT_NAME}</source>
         <translation>Iniciar o ${PRODUCT_NAME}</translation>
     </message>
     <message>
-        <source>UninstallerConfirmation</source>
+        <source>Click uninstall to begin the process.</source>
         <translation>Clique em Desinstalar para iniciar o processo.</translation>
     </message>
     <message>
-        <source>UninstallPreviousVersion</source>
-        <translation>Desinstalando versão anterior do ${PRODUCT_NAME}</translation>
+        <source>Uninstalling previous version of ${PRODUCT_NAME}...</source>
+        <translation>Desinstalando versão anterior do ${PRODUCT_NAME}...</translation>
     </message>
     <message>
-        <source>UninstallPreviousVersionError</source>
+        <source>Uninstalling the old ${PRODUCT_NAME} installation failed! Continuing will delete EVERYTHING in $3.</source>
         <translation>Falha ao desinstalar a versão antiga do ${PRODUCT_NAME}! Continuar irá excluir TUDO em $3.</translation>
     </message>
     <message>
-        <source>UninstallExecutionError</source>
+        <source>Error executing uninstaller.</source>
         <translation>Erro ao executar desinstalador.</translation>
     </message>
     <message>
-        <source>StopBirdtray</source>
+        <source>${PRODUCT_NAME} is currently running. Press OK to stop ${PRODUCT_NAME} to continue with the installation.</source>
         <translation>O ${PRODUCT_NAME} está em execução. Pressione OK para encerrar o ${PRODUCT_NAME} e prosseguir com a instalação.</translation>
     </message>
     <message>
-        <source>StoppingBirdtray</source>
-        <translation>Encerrando processo ${EXE_NAME}</translation>
+        <source>Closing process ${EXE_NAME}...</source>
+        <translation>Encerrando processo ${EXE_NAME}...</translation>
     </message>
     <message>
-        <source>StopBirdtrayError</source>
+        <source>Failed to close ${PRODUCT_NAME}. Please retry or quit ${PRODUCT_NAME} manually to continue with the installation.</source>
         <translation>Falha ao encerrar o ${PRODUCT_NAME}. Por favor, tente novamente ou feche o ${PRODUCT_NAME} manualmente para continuar com a instalação.</translation>
     </message>
     <message>
-        <source>StopBirdtrayUninstall</source>
+        <source>${PRODUCT_NAME} is currently running. Press OK to stop ${PRODUCT_NAME} to continue with the uninstall.</source>
         <translation>O ${PRODUCT_NAME} está em execução. Pressione OK para encerrar o ${PRODUCT_NAME} e continuar com a desinstalação.</translation>
     </message>
     <message>
-        <source>StopBirdtrayUninstallError</source>
+        <source>Failed to close ${PRODUCT_NAME}. Please retry or quit ${PRODUCT_NAME} manually to continue with the uninstall.</source>
         <translation>Falha ao fechar o ${PRODUCT_NAME}. Por favor, tente novamente ou feche o ${PRODUCT_NAME} manualmente para continuar com a desinstalação.</translation>
     </message>
     <message>
-        <source>SetupAlreadyRunning</source>
-        <translation>A instalação do ${PRODUCT_NAME} já está em execução.$\r$\nPor favor, feche todas as instâncias e clique em Repetir para continuar, ou Cancelar para sair.</translation>
+        <source>The setup of ${PRODUCT_NAME} is already running.
+Please, close all instances of it and click Retry to continue, or Cancel to exit.</source>
+        <translation>A instalação do ${PRODUCT_NAME} já está em execução.
+Por favor, feche todas as instâncias e clique em Repetir para continuar, ou Cancelar para sair.</translation>
     </message>
     <message>
-        <source>UninstallAlreadyRunning</source>
-        <translation>A desinstalação do ${PRODUCT_NAME} já está em execução.$\r$\nPor favor, feche todas as instâncias e clique em Repetir para continuar, ou Cancelar para sair.</translation>
+        <source>The uninstall of ${PRODUCT_NAME} is already running.
+Please, close all instances of it and click Retry to continue, or Cancel to exit.</source>
+        <translation>A desinstalação do ${PRODUCT_NAME} já está em execução.
+Por favor, feche todas as instâncias e clique em Repetir para continuar, ou Cancelar para sair.</translation>
     </message>
     <message>
-        <source>BadInstallPath</source>
-        <translation>O caminho de instalação não pode conter os seguintes caracteres:$\r$\n${BAD_PATH_CHARS}.</translation>
+        <source>The install path must not contain any of:
+${BAD_PATH_CHARS}</source>
+        <translation>O caminho de instalação não pode conter os seguintes caracteres:
+${BAD_PATH_CHARS}</translation>
     </message>
     <message>
-        <source>InstallPathContainsPreviousVersion</source>
+        <source>The install path contains a previously installed ${PRODUCT_NAME} version, which will be replaced.</source>
         <translation>O caminho de instalação contém uma versão prévia do ${PRODUCT_NAME} instalada, que será substituída.</translation>
     </message>
     <message>
-        <source>InstallPathNotEmpty</source>
+        <source>The install path is not empty, but it doesn't look like it contains a previous ${PRODUCT_NAME} installation. The content will get overwritten.</source>
         <translation>O caminho de instalação não está vazio, mas não parece que ele contém uma instalação prévia do ${PRODUCT_NAME}. O conteúdo será sobrescrito.</translation>
     </message>
     <message>
-        <source>CurrentUserOnly</source>
+        <source>$0 (current user only)</source>
         <translation>$0 (somente usuário atual)</translation>
     </message>
     <message>
-        <source>InstallFailed</source>
-        <translation>O ${PRODUCT_NAME} ${VERSION} não pôde ser totalmente instalado.$\r$\n\Por favor, reinicie o Windows e execute o programa de instalação novamente.</translation>
+        <source>${PRODUCT_NAME} ${VERSION} could not be fully installed.
+Please, restart Windows and run the setup program again.</source>
+        <translation>O ${PRODUCT_NAME} ${VERSION} não pôde ser totalmente instalado.
+Por favor, reinicie o Windows e execute o programa de instalação novamente.</translation>
     </message>
     <message>
-        <source>InstallFailedCauseUninstallerFailed</source>
-        <translation>O ${PRODUCT_NAME} não pôde ser totalmente instalado.$\r$\n\Por favor, reinicie o Windows e execute o programa de instalação novamente.</translation>
+        <source>${PRODUCT_NAME} could not be fully installed.
+Please, restart Windows and run the setup program again.</source>
+        <translation>O ${PRODUCT_NAME} não pôde ser totalmente instalado.
+Por favor, reinicie o Windows e execute o programa de instalação novamente.</translation>
     </message>
     <message>
-        <source>UninstallFailed</source>
-        <translation>O ${PRODUCT_NAME} ${VERSION} não pôde ser totalmente desinstalado.$\r$\n\Por favor, reinicie o Windows e execute o programa de desinstalação novamente.</translation>
+        <source>${PRODUCT_NAME} ${VERSION} could not be fully uninstalled.
+Please, restart Windows and run the uninstaller again.</source>
+        <translation>O ${PRODUCT_NAME} ${VERSION} não pôde ser totalmente desinstalado.
+Por favor, reinicie o Windows e execute o programa de desinstalação novamente.</translation>
     </message>
     <message>
-        <source>FileDeleteErrorDialog</source>
-        <translation>Erro ao excluir arquivo:$\r$\n$\r$\n$0$\r$\n$\r$\nClique em Repetir para tentar novamente, ou$\r$\nCancelar para parar a instalação.</translation>
+        <source>Error deleting file:
+
+$0
+
+Click Retry to try again, or
+Cancel to stop the uninstall.</source>
+        <translation>Erro ao excluir arquivo:
+
+$0
+
+Clique em Repetir para tentar novamente, ou
+Cancelar para parar a instalação.</translation>
     </message>
     <message>
-        <source>FileDeleteError</source>
+        <source>Error deleting file $0</source>
         <translation>Erro ao excluir arquivo $0</translation>
     </message>
     <message>
-        <source>Install64On32BitWarning</source>
+        <source>You are about to install the 32-bit version of ${PRODUCT_NAME} on your 64-bit Windows. There is a 64-bit version of ${PRODUCT_NAME} available for download.</source>
         <translation>Você está prestes a instalar a versão de 32 bits do ${PRODUCT_NAME} no seu Windows de 64 bits. Há uma versão de 64 bits do ${PRODUCT_NAME} disponível para download.</translation>
     </message>
     <message>
-        <source>Install32On64BitError</source>
+        <source>This installer contains the 64-bit version of ${PRODUCT_NAME}. Your computer is running a 32-bit version of Windows, which can not execute 64-bit programs. Please download the 32-bit installer of ${PRODUCT_NAME}.</source>
         <translation>Este instalador contém a versão de 64 bits do ${PRODUCT_NAME}. Seu computador está executando uma versão de 32 bits do Windows, que não pode executar programas de 64 bits. Por favor, baixe o instalador de 32 bits do ${PRODUCT_NAME}.</translation>
     </message>
     <message>
-        <source>UnsupportedWindowsVersionError</source>
+        <source>This program requires at least Windows ${MIN_WINDOWS_VER}.</source>
         <translation>Este programa necessita pelo menos do Windows ${MIN_WINDOWS_VER}.</translation>
     </message>
     <message>
-        <source>UninstallerAborted</source>
+        <source>Uninstalling ${PRODUCT_NAME} has been aborted. Please try again later.</source>
         <translation>A desinstalação do ${PRODUCT_NAME} foi cancelada. Por favor, tente novamente mais tarde.</translation>
     </message>
     <message>
-        <source>SettingsLink</source>
+        <source>${PRODUCT_NAME} settings</source>
         <translation>Configurações do ${PRODUCT_NAME}</translation>
     </message>
     <message>
-        <source>UninstallRestartAsUserQuestion</source>
+        <source>The uninstaller is started with administrator privileges but there seems to be no ${PRODUCT_NAME} installation for the administrator. Do you want to restart the uninstaller without admin privileges?</source>
         <translation>O desinstalador foi iniciado com privilégios de administrador, mas parece que não há instalação do ${PRODUCT_NAME} para o administrador. Deseja reiniciar o desinstalador sem privilégios de administrador?</translation>
     </message>
     <message>
-        <source>OpenUrl</source>
+        <source>Opening $0 in default browser...</source>
         <translation>Abrindo $0 no navegador padrão...</translation>
     </message>
     <message>
-        <source>MissingVcRuntime</source>
+        <source>Unable to find Visual C++ Runtime ${ARCH}.</source>
         <translation>Não foi possível encontrar o Visual C++ Runtime ${ARCH}.</translation>
     </message>
     <message>
-        <source>MissingVcRuntime_Dialog</source>
-        <translation>O seguinte componente necessário não foi encontrado neste computador:$\r$\nVisual C++ Runtime ${ARCH}$\r$\nDeseja baixar o instalador para o componente?</translation>
+        <source>The following required component was not found on this computer:
+Visual C++ Runtime ${ARCH}
+Do you want to download the installer for the component?</source>
+        <translation>O seguinte componente necessário não foi encontrado neste computador:
+Visual C++ Runtime ${ARCH}
+Deseja baixar o instalador para o componente?</translation>
     </message>
     <message>
-        <source>MissingVcRuntime_Retry</source>
+        <source>Once the download completes, please execute the downloaded installer. When the installer is finished, press OK to check the installation status again.</source>
         <translation>Assim que o download for concluído, execute o instalador baixado. Quando o instalador for concluído, pressione OK para verificar o status da instalação novamente.</translation>
     </message>
     <message>
-        <source>MissingVcRuntime_Found</source>
+        <source>The required component was successfully detected on your computer.</source>
         <translation>O componente necessário foi detectado com sucesso no seu computador.</translation>
     </message>
     <message>
-        <source>MissingVcRuntime_StillNotFound</source>
+        <source>The required component was not found on your computer. Please search online for Visual C++ ${ARCH} downloads for Visual Studio 2015 and higher.</source>
         <translation>O componente necessário não foi encontrado no seu computador. Por favor, pesquise por downloads do Visual C++ ${ARCH} para o Visual Studio 2015 ou superior.</translation>
     </message>
     <message>
-        <source>MissingVcRuntime_UnableToRun</source>
+        <source>${PRODUCT_NAME} will not be able to run.</source>
         <translation>O ${PRODUCT_NAME} não será capaz de ser executado.</translation>
     </message>
     <message>
-        <source>MissingVcRuntime_UnableToRunDialog</source>
+        <source>${PRODUCT_NAME} will not be able to start because a required component is missing.</source>
         <translation>O ${PRODUCT_NAME} não será capaz de ser iniciado pois um componente necessário está faltando.</translation>
     </message>
     <message>
-        <source>Lang_en</source>
+        <source>English</source>
         <translation>Inglês</translation>
     </message>
     <message>
-        <source>Lang_de</source>
+        <source>French</source>
+        <translation>Francês</translation>
+    </message>
+    <message>
+        <source>German</source>
         <translation>Alemão</translation>
     </message>
     <message>
-        <source>Lang_nl</source>
+        <source>Dutch</source>
         <translation>Holandês</translation>
     </message>
     <message>
-        <source>Lang_it</source>
+        <source>Italian</source>
         <translation>Italiano</translation>
     </message>
     <message>
-        <source>Lang_ru</source>
+        <source>Russian</source>
         <translation>Russo</translation>
     </message>
     <message>
-        <source>Lang_pt</source>
+        <source>Portugees</source>
         <translation>Português</translation>
     </message>
     <message>
-        <source>Lang_es</source>
+        <source>Spanish</source>
         <translation>Espanhol</translation>
     </message>
     <message>
-        <source>Lang_sv</source>
+        <source>Swedish</source>
         <translation>Sueco</translation>
     </message>
     <message>
-        <source>Lang_tr</source>
+        <source>Turkish</source>
         <translation>Turco</translation>
     </message>
     <message>
-        <source>Lang_pl</source>
+        <source>Polish</source>
         <translation>Polaca</translation>
     </message>
+    <message>
+        <source>Chinese (Simplified)</source>
+        <translation>Chinês (Simplificado)</translation>
+    </message>
+    <message>
+        <source>Greek</source>
+        <translation>Grego</translation>
+    </message>
+    <message>
+        <source>Czech</source>
+        <translation>Tcheco</translation>
+    </message>
 </context>
 </TS>
